"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useYoutube = void 0;
const react_1 = require("react");
const types_1 = require("./types");
let player;
const initializeIframe = (id) => {
    const iframe = document.createElement("div");
    iframe.id = `youtube-player-${id}`;
    iframe.style.setProperty("display", "none");
    document.body.appendChild(iframe);
};
const loadApi = (id, options) => {
    if (document.querySelector("[data-youtube]") && window.YT) {
        player = new YT.Player(`youtube-player-${id}`, options);
        return;
    }
    const tag = document.createElement("script");
    tag.src = "https://www.youtube.com/iframe_api";
    tag.dataset.youtube = "true";
    const firstScriptTag = document.getElementsByTagName("head")[0];
    firstScriptTag.appendChild(tag);
    window.onYouTubeIframeAPIReady = () => {
        player = new YT.Player(`youtube-player-${id}`, options);
    };
};
exports.useYoutube = ({ id, type, options, events, }) => {
    const getPlayerOptions = (type, options) => ({
        videoId: type === "video" ? id : undefined,
        host: options?.host,
        playerVars: {
            listType: type === "playlist" ? type : undefined,
            list: type === "playlist" ? id : undefined,
            origin: options?.origin,
            autoplay: options?.autoplay ? 1 : 0,
            loop: options?.loop ? 1 : 0,
            mute: options?.mute ? 1 : 0,
            start: options?.start,
            end: options?.end,
        },
        events: {
            onReady: (event) => {
                setState(event.target);
                events?.onReady?.(event);
            },
            onStateChange: (event) => {
                setState(event.target);
                events?.onStateChange?.(event);
            },
            onError: (event) => {
                events?.onError?.(event);
            },
        },
    });
    const [playerDetails, setPlayerDetails] = react_1.useState({
        id: "",
        state: types_1.PlayerState.UNSTARTED,
        title: "",
        duration: 0,
        currentTime: 0,
        volume: 0,
    });
    react_1.useEffect(() => {
        initializeIframe(id);
        loadApi(id, getPlayerOptions(type, options));
        return () => {
            player?.destroy();
        };
    }, [id, type]);
    const setState = ({ playerInfo: { videoData, ...playerInfo }, }) => {
        setPlayerDetails({
            id: videoData.video_id,
            state: playerInfo.playerState,
            title: videoData.title,
            duration: playerInfo.duration,
            volume: playerInfo.volume,
            currentTime: playerInfo.currentTime,
        });
    };
    const proxy = (functionName, args = []) => {
        if (typeof player?.[functionName] === "function") {
            player[functionName].call(player, ...args);
        }
        else {
            console.error("Player not initialized.");
        }
    };
    return {
        playerDetails,
        actions: {
            playVideo: () => proxy("playVideo"),
            stopVideo: () => proxy("stopVideo"),
            pauseVideo: () => proxy("pauseVideo"),
            nextVideo: () => proxy("nextVideo"),
            previousVideo: () => proxy("previousVideo"),
            setVolume: (volume) => {
                setPlayerDetails((prevState) => ({ ...prevState, volume }));
                proxy("setVolume", [volume]);
            },
            seekTo: (seconds, allowSeekAhead) => {
                setPlayerDetails((prevState) => ({
                    ...prevState,
                    currentTime: seconds,
                }));
                proxy("seekTo", [seconds, allowSeekAhead]);
            },
        },
    };
};
//# sourceMappingURL=useYoutube.js.map